==> style-o-matic-1.1.3.tgz: package/es/components/Header/Header.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import { CoreComponent, getValidProps, getCorePropDefaults, ROLE } from "../../lib";
import "./Header.css";

var Header = (_temp2 = _class = function (_CoreComponent) {
  _inherits(Header, _CoreComponent);

  function Header() {
    var _temp, _this, _ret;

    _classCallCheck(this, Header);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args))), _this), _this.renderChild = function (child, props) {
      var role = child.props.uirole;
      var ref = function ref(c) {
        _this[role] = c;
      };
      if (typeof child.ref !== "string") {
        ref = _this.chainFunction(child.ref, ref);
      }
      return cloneElement(child, _extends({}, props, {
        ref: ref,
        uiclass: _this.childPrefix(role)
      }));
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Header.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        uiclass = _getValidProps.uiclass,
        fixed = _getValidProps.fixed,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var output = [];

    output.push(React.createElement(
      Component,
      _extends({}, props, { key: "header" }),
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          switch (child.props.uirole) {
            case ROLE.CONTENT:
              return _this2.renderChild(child, { uiclass: uiclass });
            default:
              return child;
          }
        }
        return child;
      })
    ));

    if (fixed) {
      output.push(React.createElement("div", { className: "ui-header-bolster", key: "header-bolster" }));
    }

    return output;
  };

  return Header;
}(CoreComponent), _class.defaultProps = getCorePropDefaults({
  renderAs: "header",
  uirole: ROLE.HEADER
}), _temp2);


export default Header;

==> style-o-matic-1.1.5.tgz: package/es/components/Header/Header.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp, _class2, _temp3;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import { CoreComponent, getValidProps, setCorePropDefaults, ROLE } from "../../lib";
import Drawer from "../Drawer/Drawer.js";
import HeaderContent from "./HeaderContent.js";
import "./Header.css";

var HeaderDrawer = (_temp = _class = function (_Drawer) {
  _inherits(HeaderDrawer, _Drawer);

  function HeaderDrawer() {
    _classCallCheck(this, HeaderDrawer);

    return _possibleConstructorReturn(this, _Drawer.apply(this, arguments));
  }

  return HeaderDrawer;
}(Drawer), _class.defaultProps = {
  renderAs: "div",
  uirole: ROLE.DRAWER,
  attach: "top"
}, _temp);
var Header = (_temp3 = _class2 = function (_CoreComponent) {
  _inherits(Header, _CoreComponent);

  function Header() {
    var _temp2, _this2, _ret;

    _classCallCheck(this, Header);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp2 = (_this2 = _possibleConstructorReturn(this, _CoreComponent.call.apply(_CoreComponent, [this].concat(args))), _this2), _this2.renderChild = function (child, props) {
      var role = child.props.uirole;
      var ref = function ref(c) {
        _this2[role] = c;
      };
      if (typeof child.ref !== "string") {
        ref = _this2.chainFunction(child.ref, ref);
      }
      return cloneElement(child, _extends({}, props, {
        ref: ref,
        uiclass: _this2.childPrefix(role)
      }));
    }, _temp2), _possibleConstructorReturn(_this2, _ret);
  }

  Header.prototype.render = function render() {
    var _this3 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        uiclass = _getValidProps.uiclass,
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      Component,
      _extends({}, props, { key: "header" }),
      React.Children.map(children, function (child) {
        if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
          switch (child.props.uirole) {
            case ROLE.CONTENT:
              return _this3.renderChild(child, { uiclass: uiclass });
            default:
              return child;
          }
        }
        return child;
      })
    );
  };

  return Header;
}(CoreComponent), _class2.defaultProps = setCorePropDefaults({
  renderAs: "header",
  uirole: ROLE.HEADER
}), _class2.Drawer = HeaderDrawer, _class2.Content = HeaderContent, _temp3);


export default Header;
